# Test Coverage Report

Generated: Sun 2014-11-09 09:00 CET

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 337 | 295 | 42 | 100.0%
payslip.__init__ | 1 | 1 | 0 | 100.0%
payslip.forms | 129 | 121 | 8 | 100.0%
payslip.models | 49 | 32 | 17 | 100.0%
payslip.templatetags.payslip_tags | 9 | 6 | 3 | 100.0%
payslip.views | 149 | 135 | 14 | 100.0%

Excluded packages and modules
Error packages and modules